@@ -1,2 +1,4 @@
-version = "0.2.3"
+version = "0.3"
 project_url = "https://github.com/memset/sftpcloudfs"
+config_file = "/etc/sftpcloudfs.conf"
+
